@@ -88,6 +88,7 @@ class Config:
         'kaa.filetype.diff',
         'kaa.filetype.rst',
         'kaa.filetype.markdown',
+        'kaa.filetype.c',
     ]
 
     DEFAULT_NEWLINE = 'auto'
@@ -128,6 +129,8 @@ class Config:
         self.hist_grepstr = History('grep_text', self.hist_storage)
         self.hist_grepdir = History('grep_dir', self.hist_storage)
         self.hist_grepfiles = History('grep_filename', self.hist_storage)
+        self.hist_shellcommands = History('shellcommands', self.hist_storage)
+        self.hist_makecommands = History('makecommands', self.hist_storage)
 
     def get_mode_packages(self):
         for pkgname in self.FILETYPES:
