@@ -4,11 +4,10 @@ from kaa.filetype.default import modebase
 from kaa.theme import Theme, Style
 
 DialogThemes = {
-    'default':
+    'basic':
         Theme([
             Style('default', 'Base3', 'Base02', False, False),
-            Style('title', 'Base3', 'Blue', nowrap=True),
-            Style('caption', 'Menu2', 'Base02', nowrap=True),
+            Style('caption', 'Orange', 'Base02', nowrap=True),
 
             Style('activemark', 'Base02', 'Yellow', nowrap=True),
             Style('nonactivemark', 'Yellow', 'Base02', nowrap=True),
@@ -18,11 +17,11 @@ DialogThemes = {
                     rjust=True, nowrap=True),
 
             Style('checkbox', 'Base3', 'Base01', rjust=True, nowrap=True),
-            Style('checkbox.checked', 'Menu3', 'Menu2', rjust=True,
+            Style('checkbox.checked', 'Base3', 'Orange', rjust=True,
                   nowrap=True),
             Style('checkbox.shortcut', 'Base3', 'Base01', underline=True,
                   rjust=True, nowrap=True),
-            Style('checkbox.shortcut.checked', 'Menu3', 'Menu2', 
+            Style('checkbox.shortcut.checked', 'Base3', 'Orange', 
                   underline=True, rjust=True, nowrap=True),
 
             Style('selectitem', 'Cyan', 'Base02', nowrap=True),
@@ -32,7 +31,7 @@ DialogThemes = {
             Style('selectphrase', 'Black', 'Cyan', nowrap=True),
             Style('selectphrase2', 'Yellow', 'Base02', nowrap=True),
             Style('selectphrase-active', 'Base02', 'Yellow', nowrap=True),
-    ])
+    ]),
 }
 
 class DialogCursor(cursor.Cursor):
