@@ -2,14 +2,11 @@ import os
 import fnmatch
 import re
 
+from gappedbuf import re as gre
 import kaa
 from kaa import document
-from kaa.keyboard import *
 from kaa.theme import Theme, Style
-from kaa.filetype.default import modebase, keybind, defaultmode
-from kaa.ui.msgbox import msgboxmode
-from kaa.command import command, Commands, norec, norerun
-from kaa.commands import editorcommand
+from kaa.ui.filenameindex import filenameindexmode
 
 FILES_IGNORE = [
     '*.com',
@@ -133,8 +130,8 @@ def _grep(filename, regex, encoding, newline):
 def _search(dir, option, doc):
     mode = doc.mode
     style_default = mode.get_styleid('default')
-    style_filename = mode.get_styleid('grep-filename')
-    style_lineno = mode.get_styleid('grep-lineno')
+    style_filename = mode.get_styleid('filenameindex-filename')
+    style_lineno = mode.get_styleid('filenameindex-lineno')
     style_match = mode.get_styleid('grep-match')
     
     def add_hit():
@@ -215,7 +212,8 @@ def grep(option, target):
         
     doc.set_title('<grep>')
     mode.grepoption = option.clone()
-
+    mode.encoding = mode.grepoption.encoding
+    mode.newlilne = mode.grepoption.newline
         
     dir = os.path.abspath(os.path.expanduser(option.directory))
     if not os.path.isdir(dir):
@@ -239,134 +237,17 @@ def grep(option, target):
     else:
         target.activate()
     
+
 GrepThemes = {
     'basic':
         Theme([
-            Style('grep-filename', 'Green', 'Default'),
-            Style('grep-lineno', 'Green', 'Default'),
             Style('grep-match', 'Base03', 'Yellow'),
         ]),
 }
 
-
-grep_keys = {
-    '\r': ('grep.showmatch'),
-    '\n': ('grep.showmatch'),
-}
-
-
-
-class GrepMode(defaultmode.DefaultMode):
+class GrepMode(filenameindexmode.FilenameIndexMode):
     MODENAME = 'Grep'
-    DOCUMENT_MODE = False
-    USE_UNDO = False
-    HIGHLIGHT_CURSORLINE = True
 
-    GREP_KEY_BINDS = [
-        grep_keys,
-    ]
-    
     def init_themes(self):
         super().init_themes()
         self.themes.append(GrepThemes)
-
-    def init_keybind(self):
-        super().init_keybind()
-        self.register_keys(self.keybind, self.GREP_KEY_BINDS)
-
-    def _locate_doc(self, wnd, doc, lineno):
-        wnd.show_doc(doc)
-
-        pos = doc.get_lineno_pos(lineno)
-        tol = doc.gettol(pos)
-        wnd.cursor.setpos(wnd.cursor.adjust_nextpos(wnd.cursor.pos, tol))
-        wnd.activate()
-
-    @command('grep.showmatch')
-    @norec
-    @norerun
-    def show_hit(self, wnd):
-        pos = wnd.cursor.pos
-        tol = self.document.gettol(pos)
-        eol, line = self.document.getline(tol)
-
-        try:
-            filename, lineno, line = line.split(':', 2)
-        except ValueError:
-            return
-
-        if not filename:
-            return
-
-        try:
-            lineno = int(lineno)
-        except ValueError:
-            lineno = 1
-
-        filename = os.path.abspath(filename)
-        doc = document.Document.find_filename(filename)
-        if not doc:
-            enc = self.grepoption.encoding
-            if enc == 'japanese':
-                enc = _enc_japanese(filename)
-
-            doc = kaa.app.storage.openfile(
-                    filename, encoding=enc, nohist=True,
-                    newline=self.grepoption.newline)
-
-        buddy = wnd.splitter.get_buddy()
-        if not buddy:
-            buddy = wnd.splitter.split(vert=False, doc=doc)
-            self._locate_doc(buddy.wnd, doc, lineno)
-        else:
-            if buddy.wnd and buddy.wnd.document is doc:
-                self._locate_doc(buddy.wnd, doc, lineno)
-                return
-                
-            def callback(canceled):
-                if not canceled:
-                    buddy.show_doc(doc)
-                    self._locate_doc(buddy.wnd, doc, lineno)
-                
-            self.app_commands.save_splitterdocs(wnd, buddy, callback)
-            
-    def on_global_prev(self, wnd):
-        if kaa.app.focus in self.document.wnds:
-            self.show_hit(kaa.app.focus)
-            return True
-            
-        pos = wnd.cursor.pos
-        eol = self.document.gettol(pos)
-        if eol:
-            tol = self.document.gettol(eol-1)
-        else:
-            eol = self.document.endpos()
-            tol = self.document.gettol(eol)
-
-        eol, line = self.document.getline(tol)
-        if line.strip():
-            wnd.cursor.setpos(tol)
-            self.show_hit(wnd)
-        elif eol:
-            wnd.cursor.setpos(self.document.gettol(eol-1))
-            self.document.wnds[0].activate()
-
-        return True
-        
-    def on_global_next(self, wnd):
-        if kaa.app.focus in self.document.wnds:
-            self.show_hit(kaa.app.focus)
-            return True
-            
-        pos = wnd.cursor.pos
-        tol = self.document.geteol(pos)
-
-        eol, line = self.document.getline(tol)
-        if line.strip():
-            wnd.cursor.setpos(tol)
-            self.show_hit(wnd)
-        elif eol == self.document.endpos():
-            wnd.cursor.setpos(0)
-            self.document.wnds[0].activate()
-
-        return True
